import { Construct } from "constructs";
import { IParent } from "./parent";
import { IPolicyAttachmentTarget } from "./policy-attachment";
/**
 * @see https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/control-access-billing.html#ControllingAccessWebsite-Activate
 * @stability stable
 */
export declare enum IamUserAccessToBilling {
    /**
     * If set to ALLOW, the new account enables IAM users to access account billing information if they have the required permissions.
     *
     * @stability stable
     */
    ALLOW = "ALLOW",
    /**
     * If set to DENY, only the root user of the new account can access account billing information.
     *
     * @stability stable
     */
    DENY = "DENY"
}
/**
 * @stability stable
 */
export interface AccountProps {
    /**
     * The email address of the owner to assign to the new member account.
     *
     * This email address must not already be associated with another AWS account. You must use a valid email address to complete account creation. You can't access the root user of the account or remove an account that was created with an invalid email address.
     *
     * @stability stable
     */
    readonly email: string;
    /**
     * The friendly name of the member account.
     *
     * @stability stable
     */
    readonly accountName: string;
    /**
     * The name of an IAM role that AWS Organizations automatically preconfigures in the new member account.
     *
     * This role trusts the management account, allowing users in the management account to assume the role, as permitted by the management account administrator. The role has administrator permissions in the new member account.
     *
     * If you don't specify this parameter, the role name defaults to OrganizationAccountAccessRole.
     *
     * @stability stable
     */
    readonly roleName?: string;
    /**
     * If set to ALLOW , the new account enables IAM users to access account billing information if they have the required permissions.
     *
     * If set to DENY , only the root user of the new account can access account billing information.
     *
     * @default ALLOW
     * @stability stable
     */
    readonly iamUserAccessToBilling?: IamUserAccessToBilling;
    /**
     * The parent root or OU that you want to create the new Account in.
     *
     * @stability stable
     */
    readonly parent?: IParent;
}
/**
 * @stability stable
 */
export interface IAccount {
    /**
     * If the account was created successfully, the unique identifier (ID) of the new account.
     *
     * Exactly 12 digits.
     *
     * @stability stable
     */
    readonly accountId: string;
    /**
     * The friendly name of the account.
     *
     * @stability stable
     */
    readonly accountName: string;
    /**
     * The email address of the owner to assign to the new member account.
     *
     * This email address must not already be associated with another AWS account. You must use a valid email address to complete account creation. You can't access the root user of the account or remove an account that was created with an invalid email address.
     *
     * @stability stable
     */
    readonly email: string;
}
/**
 * Creates an AWS account that is automatically a member of the organization whose credentials made the request.
 *
 * AWS Organizations automatically copies the information from the management account to the new member account
 *
 * @stability stable
 */
export declare abstract class AccountBase extends Construct implements IAccount, IPolicyAttachmentTarget {
    /**
     * If the account was created successfully, the unique identifier (ID) of the new account.
     *
     * Exactly 12 digits.
     *
     * @stability stable
     */
    abstract readonly accountId: string;
    /**
     * The friendly name of the account.
     *
     * @stability stable
     */
    abstract readonly accountName: string;
    /**
     * The email address of the owner to assign to the new member account.
     *
     * This email address must not already be associated with another AWS account. You must use a valid email address to complete account creation. You can't access the root user of the account or remove an account that was created with an invalid email address.
     *
     * @stability stable
     */
    abstract readonly email: string;
    /**
     * @stability stable
     */
    identifier(): string;
    /**
     * @stability stable
     */
    currentParentId(): string;
    /**
     * @stability stable
     */
    move(destinationParentId: string, sourceParentId: string): void;
}
/**
 * @stability stable
 */
export interface AccountAttributes {
    /**
     * @stability stable
     */
    readonly accountId: string;
    /**
     * @stability stable
     */
    readonly parent: IParent;
}
/**
 * @stability stable
 */
export declare class Account extends AccountBase {
    /**
     * Import an existing account from account id.
     *
     * @stability stable
     */
    static fromAccountId(scope: Construct, id: string, attrs: AccountAttributes): IAccount;
    /**
     * If the account was created successfully, the unique identifier (ID) of the new account.
     *
     * Exactly 12 digits.
     *
     * @stability stable
     */
    readonly accountId: string;
    /**
     * The friendly name of the account.
     *
     * @stability stable
     */
    readonly accountName: string;
    /**
     * The email address of the owner to assign to the new member account.
     *
     * This email address must not already be associated with another AWS account. You must use a valid email address to complete account creation. You can't access the root user of the account or remove an account that was created with an invalid email address.
     *
     * @stability stable
     */
    readonly email: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: AccountProps);
}
